IF "%CONDA_BUILD%" == "" (
    call C:\bld\r-sf_1562020488148\work\build_env_setup.bat
)
REM ===== end generated header =====
mkdir %PREFIX%\lib\R\library
robocopy /E . "%PREFIX%\lib\R\library\sf"
if %ERRORLEVEL% NEQ 1 exit 1
exit 0
